Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(110)

Unified Diff: src/gpu/glsl/GrGLSLPrimitiveProcessor.h

Issue 1441683008: Move GrGLPrimitive/GeometryProc to GLSL (Closed) Base URL: https://skia.googlesource.com/skia.git@xferProcs
Patch Set: nits Created 5 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/gpu/glsl/GrGLSLGeometryProcessor.cpp ('k') | src/gpu/glsl/GrGLSLPrimitiveProcessor.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/gpu/glsl/GrGLSLPrimitiveProcessor.h
diff --git a/src/gpu/gl/GrGLPrimitiveProcessor.h b/src/gpu/glsl/GrGLSLPrimitiveProcessor.h
similarity index 87%
rename from src/gpu/gl/GrGLPrimitiveProcessor.h
rename to src/gpu/glsl/GrGLSLPrimitiveProcessor.h
index 0f3c42e52521f2f1c368ea0a7e557f30d521a20d..537aaed8f254ee95e8c349c7aa6e3d21ba9fe545 100644
--- a/src/gpu/gl/GrGLPrimitiveProcessor.h
+++ b/src/gpu/glsl/GrGLSLPrimitiveProcessor.h
@@ -5,8 +5,8 @@
* found in the LICENSE file.
*/
-#ifndef GrGLPrimitiveProcessor_DEFINED
-#define GrGLPrimitiveProcessor_DEFINED
+#ifndef GrGLSLPrimitiveProcessor_DEFINED
+#define GrGLSLPrimitiveProcessor_DEFINED
#include "GrPrimitiveProcessor.h"
#include "glsl/GrGLSLProcessorTypes.h"
@@ -17,9 +17,9 @@ class GrBatchTracker;
class GrPrimitiveProcessor;
class GrGLSLGPBuilder;
-class GrGLPrimitiveProcessor {
+class GrGLSLPrimitiveProcessor {
public:
- virtual ~GrGLPrimitiveProcessor() {}
+ virtual ~GrGLSLPrimitiveProcessor() {}
typedef GrGLSLProgramDataManager::UniformHandle UniformHandle;
typedef GrGLSLTextureSampler::TextureSamplerArray TextureSamplerArray;
@@ -59,12 +59,12 @@ public:
virtual void emitCode(EmitArgs&) = 0;
- /** A GrGLPrimitiveProcessor instance can be reused with any GrGLPrimitiveProcessor that
- produces the same stage key; this function reads data from a GrGLPrimitiveProcessor and
+ /** A GrGLSLPrimitiveProcessor instance can be reused with any GrGLSLPrimitiveProcessor that
+ produces the same stage key; this function reads data from a GrGLSLPrimitiveProcessor and
uploads any uniform variables required by the shaders created in emitCode(). The
GrPrimitiveProcessor parameter is guaranteed to be of the same type that created this
- GrGLPrimitiveProcessor and to have an identical processor key as the one that created this
- GrGLPrimitiveProcessor. */
+ GrGLSLPrimitiveProcessor and to have an identical processor key as the one that created this
+ GrGLSLPrimitiveProcessor. */
virtual void setData(const GrGLSLProgramDataManager&, const GrPrimitiveProcessor&) = 0;
static SkMatrix GetTransformMatrix(const SkMatrix& localMatrix, const GrCoordTransform&);
« no previous file with comments | « src/gpu/glsl/GrGLSLGeometryProcessor.cpp ('k') | src/gpu/glsl/GrGLSLPrimitiveProcessor.cpp » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698